@@ -25,7 +25,7 @@
 /**
  *	\file src/Matrices.cpp
  *	\author Hans Joachim Ferreau, Andreas Potschka, Christian Kirches
- *	\version 3.1
+ *	\version 3.2
  *	\date 2007-2015
  *
  *	Implementation of the matrix classes.
@@ -43,6 +43,58 @@ BEGIN_NAMESPACE_QPOASES
  *  P U B L I C                                                              *
  *****************************************************************************/
 
+returnValue Matrix::getSparseSubmatrix(
+				const Indexlist* const irows,
+				const Indexlist* const icols,
+				int_t rowoffset,
+				int_t coloffset,
+				int_t& numNonzeros,
+				int_t* irn,
+				int_t* jcn,
+				real_t* avals,
+				BooleanType only_lower_triangular) const
+{
+	int_t* rowsNumbers;
+	irows->getNumberArray( &rowsNumbers );
+	int_t* colsNumbers;
+	icols->getNumberArray( &colsNumbers );
+
+	return getSparseSubmatrix(irows->getLength(), rowsNumbers, icols->getLength(), colsNumbers, rowoffset, coloffset, numNonzeros, irn, jcn, avals, only_lower_triangular);
+}
+
+returnValue Matrix::getSparseSubmatrix(
+				const Indexlist* const irows,
+				int_t idx_icol,
+				int_t rowoffset,
+				int_t coloffset,
+				int_t& numNonzeros,
+				int_t* irn,
+				int_t* jcn,
+				real_t* avals,
+				BooleanType only_lower_triangular) const
+{
+	int_t* rowsNumbers;
+	irows->getNumberArray( &rowsNumbers );
+
+	return getSparseSubmatrix(irows->getLength(), rowsNumbers, 1, &idx_icol, rowoffset, coloffset, numNonzeros, irn, jcn, avals, only_lower_triangular);
+}
+
+returnValue Matrix::getSparseSubmatrix(
+				int_t idx_row,
+				const Indexlist* const icols,
+				int_t rowoffset,
+				int_t coloffset,
+				int_t& numNonzeros,
+				int_t* irn,
+				int_t* jcn,
+				real_t* avals,
+				BooleanType only_lower_triangular) const
+{
+	int_t* colsNumbers;
+	icols->getNumberArray( &colsNumbers );
+
+	return getSparseSubmatrix(1, &idx_row, icols->getLength(), colsNumbers, rowoffset, coloffset, numNonzeros, irn, jcn, avals, only_lower_triangular);
+}
 
 
 DenseMatrix::~DenseMatrix()
@@ -65,7 +117,7 @@ Matrix *DenseMatrix::duplicate( ) const
 	if ( needToFreeMemory( ) == BT_TRUE )
 	{
 		real_t* val_new = new real_t[nRows*nCols];
-		memcpy( val_new,val, ((unsigned int)(nRows*nCols))*sizeof(real_t) );
+		memcpy( val_new,val, ((uint_t)(nRows*nCols))*sizeof(real_t) );
 		dupl = new DenseMatrix(nRows, nCols, nCols, val_new);
 		dupl->doFreeMemory( );
 	}
@@ -77,7 +129,7 @@ Matrix *DenseMatrix::duplicate( ) const
 	return dupl;
 }
 
-real_t DenseMatrix::diag(	int i
+real_t DenseMatrix::diag(	int_t i
 							) const
 {
 	return val[i*(leaDim+1)];
@@ -85,7 +137,7 @@ real_t DenseMatrix::diag(	int i
 
 BooleanType DenseMatrix::isDiag( ) const
 {
-	int i, j;
+	int_t i, j;
 
 	if (nRows != nCols)
 		return BT_FALSE;
@@ -99,21 +151,21 @@ BooleanType DenseMatrix::isDiag( ) const
 }
 
 
-real_t DenseMatrix::getNorm(	int type
+real_t DenseMatrix::getNorm(	int_t type
 								) const
 {
-	return REFER_NAMESPACE_QPOASES getNorm( val,nCols*nRows,type ); 
+	return REFER_NAMESPACE_QPOASES getNorm( val,nCols*nRows,type );
 }
 
 
-real_t DenseMatrix::getRowNorm( int rNum, int type ) const
+real_t DenseMatrix::getRowNorm( int_t rNum, int_t type ) const
 {
-	return REFER_NAMESPACE_QPOASES getNorm( &(val[rNum*leaDim]),nCols,type ); 
+	return REFER_NAMESPACE_QPOASES getNorm( &(val[rNum*leaDim]),nCols,type );
 }
 
-returnValue DenseMatrix::getRow(int rNum, const Indexlist* const icols, real_t alpha, real_t *row) const
+returnValue DenseMatrix::getRow(int_t rNum, const Indexlist* const icols, real_t alpha, real_t *row) const
 {
-	int i;
+	int_t i;
     if (icols != 0)
     {
 	    if ( isEqual(alpha,1.0) == BT_TRUE )
@@ -142,9 +194,9 @@ returnValue DenseMatrix::getRow(int rNum, const Indexlist* const icols, real_t a
 }
 
 
-returnValue DenseMatrix::getCol(int cNum, const Indexlist* const irows, real_t alpha, real_t *col) const
+returnValue DenseMatrix::getCol(int_t cNum, const Indexlist* const irows, real_t alpha, real_t *col) const
 {
-	int i;
+	int_t i;
 
 	if ( isEqual(alpha,1.0) == BT_TRUE )
 		for (i = 0; i < irows->length; i++)
@@ -159,8 +211,86 @@ returnValue DenseMatrix::getCol(int cNum, const Indexlist* const irows, real_t a
 	return SUCCESSFUL_RETURN;
 }
 
+returnValue DenseMatrix::getSparseSubmatrix (int_t irowsLength, const int_t* const irowsNumber,
+											 int_t icolsLength, const int_t* const icolsNumber,
+											 int_t rowoffset, int_t coloffset, int_t& numNonzeros,	int_t* irn,
+											 int_t* jcn, real_t* avals,
+											 BooleanType only_lower_triangular /*= BT_FALSE */) const
+{
+	int_t i, j, irA;
+	real_t v;
+	numNonzeros = 0;
+	if ( only_lower_triangular == BT_FALSE )
+	{
+		if (irn == 0)
+		{
+			if (jcn != 0 || avals != 0)
+				return THROWERROR( RET_INVALID_ARGUMENTS );
+			for (j = 0; j<irowsLength; j++)
+			{
+				irA = irowsNumber[j] * leaDim;
+				for (i = 0; i<icolsLength; i++)
+					if (isZero( val[irA+icolsNumber[i]] ) == BT_FALSE)
+						numNonzeros++;
+			}
+		}
+		else
+		{
+			for (j = 0; j<irowsLength; j++)
+			{
+				irA = irowsNumber[j] * leaDim;
+				for (i = 0; i<icolsLength; i++)
+				{
+					v = val[irA+icolsNumber[i]];
+					if (isZero( v ) == BT_FALSE)
+					{
+						irn[numNonzeros] = j+rowoffset;
+						jcn[numNonzeros] = i+coloffset;
+						avals[numNonzeros] = v;
+						numNonzeros++;
+					}
+				}
+			}
+		}
+	}
+	else
+	{
+		if (irn == 0)
+		{
+			if (jcn != 0 || avals != 0)
+				return THROWERROR( RET_INVALID_ARGUMENTS );
+			for (j = 0; j<irowsLength; j++)
+			{
+				irA = irowsNumber[j] * leaDim;
+				for (i = 0; i<=j; i++)
+					if (isZero( val[irA+irowsNumber[i]] ) == BT_FALSE)
+						numNonzeros++;
+			}
+		}
+		else
+		{
+			for (j = 0; j<irowsLength; j++)
+			{
+				irA = irowsNumber[j] * leaDim;
+				for (i = 0; i<=j; i++)
+				{
+					v = val[irA+irowsNumber[i]];
+					if (isZero( v ) == BT_FALSE)
+					{
+						irn[numNonzeros] = j+rowoffset;
+						jcn[numNonzeros] = i+coloffset;
+						avals[numNonzeros] = v;
+						numNonzeros++;
+					}
+				}
+			}
+		}
+	}
 
-returnValue DenseMatrix::times(	int xN, real_t alpha, const real_t *x, int xLD, real_t beta, real_t *y, int yLD) const
+	return SUCCESSFUL_RETURN;
+}
+
+returnValue DenseMatrix::times(	int_t xN, real_t alpha, const real_t *x, int_t xLD, real_t beta, real_t *y, int_t yLD) const
 {
 	unsigned long _xN     = (unsigned long)xN;
 	unsigned long _nRows  = (unsigned long)nRows;
@@ -174,7 +304,7 @@ returnValue DenseMatrix::times(	int xN, real_t alpha, const real_t *x, int xLD,
 	return SUCCESSFUL_RETURN;
 }
 
-returnValue DenseMatrix::transTimes( int xN, real_t alpha, const real_t *x, int xLD, real_t beta, real_t *y, int yLD) const
+returnValue DenseMatrix::transTimes( int_t xN, real_t alpha, const real_t *x, int_t xLD, real_t beta, real_t *y, int_t yLD) const
 {
 	unsigned long _xN     = (unsigned long)xN;
 	unsigned long _nRows  = (unsigned long)nRows;
@@ -189,10 +319,10 @@ returnValue DenseMatrix::transTimes( int xN, real_t alpha, const real_t *x, int
 }
 
 returnValue DenseMatrix::times(	const Indexlist* const irows, const Indexlist* const icols,
-								int xN, real_t alpha, const real_t *x, int xLD, real_t beta, real_t *y, int yLD,
+								int_t xN, real_t alpha, const real_t *x, int_t xLD, real_t beta, real_t *y, int_t yLD,
 								BooleanType yCompr) const
 {
-	int i, j, k, row, col, iy, irA;
+	int_t i, j, k, row, col, iy, irA;
 
 	if (yCompr == BT_TRUE)
 	{
@@ -373,9 +503,9 @@ returnValue DenseMatrix::times(	const Indexlist* const irows, const Indexlist* c
 }
 
 returnValue DenseMatrix::transTimes(	const Indexlist* const irows, const Indexlist* const icols,
-										int xN, real_t alpha, const real_t *x, int xLD, real_t beta, real_t *y, int yLD) const
+										int_t xN, real_t alpha, const real_t *x, int_t xLD, real_t beta, real_t *y, int_t yLD) const
 {
-	int i, j, k, row, col;
+	int_t i, j, k, row, col;
 
 	if ( isZero(beta) == BT_TRUE )
 		for (k = 0; k < xN; k++)
@@ -430,7 +560,7 @@ returnValue DenseMatrix::transTimes(	const Indexlist* const irows, const Indexli
 
 returnValue DenseMatrix::addToDiag( real_t alpha )
 {
-	int i;
+	int_t i;
 	for (i = 0; i < nRows && i < nCols; i++)
 		val[i*(leaDim+1)] += alpha;
 
@@ -438,10 +568,16 @@ returnValue DenseMatrix::addToDiag( real_t alpha )
 }
 
 
+returnValue DenseMatrix::writeToFile( FILE* output_file, const char* prefix ) const
+{
+	return THROWERROR( RET_NOT_YET_IMPLEMENTED );
+}
+
+
 real_t* DenseMatrix::full() const
 {
 	real_t* v = new real_t[nRows*nCols];
-	memcpy( v,val, ((unsigned int)(nRows*nCols))*sizeof(real_t) );
+	memcpy( v,val, ((uint_t)(nRows*nCols))*sizeof(real_t) );
 	return v;
 }
 
@@ -467,7 +603,7 @@ SymmetricMatrix *SymDenseMat::duplicateSym( ) const
 	if ( needToFreeMemory( ) == BT_TRUE )
 	{
 		real_t* val_new = new real_t[nRows*nCols];
-		memcpy( val_new,val, ((unsigned int)(nRows*nCols))*sizeof(real_t) );
+		memcpy( val_new,val, ((uint_t)(nRows*nCols))*sizeof(real_t) );
 		dupl = new SymDenseMat(nRows, nCols, nCols, val_new);
 		dupl->doFreeMemory( );
 	}
@@ -481,10 +617,10 @@ SymmetricMatrix *SymDenseMat::duplicateSym( ) const
 
 
 returnValue SymDenseMat::bilinear(	const Indexlist* const icols,
-									int xN, const real_t *x, int xLD, real_t *y, int yLD) const
+									int_t xN, const real_t *x, int_t xLD, real_t *y, int_t yLD) const
 {
-	int ii, jj, kk, col;
-	int i,j,k,irA;
+	int_t ii, jj, kk, col;
+	int_t i,j,k,irA;
 
 	for (ii = 0; ii < xN; ii++)
 		for (jj = 0; jj < xN; jj++)
@@ -523,15 +659,13 @@ returnValue SymDenseMat::bilinear(	const Indexlist* const icols,
 
 SparseMatrix::SparseMatrix() : nRows(0), nCols(0), ir(0), jc(0), jd(0), val(0) {}
 
-
-SparseMatrix::SparseMatrix( int nr, int nc, sparse_int_t *r, sparse_int_t *c, real_t *v )
+SparseMatrix::SparseMatrix(	int_t nr, int_t nc, sparse_int_t *r, sparse_int_t *c, real_t *v)
 								: nRows(nr), nCols(nc), ir(r), jc(c), jd(0), val(v) { doNotFreeMemory(); }
 
-
-SparseMatrix::SparseMatrix( int nr, int nc, int ld, const real_t * const v ) 
+SparseMatrix::SparseMatrix(	int_t nr, int_t nc, int_t ld, const real_t * const v)
 								: nRows(nr), nCols(nc), jd(0)
 {
-	int i, j, nnz;
+	int_t i, j, nnz;
 
 	jc = new sparse_int_t[nc+1];
 	ir = new sparse_int_t[nr*nc];
@@ -601,7 +735,7 @@ Matrix *SparseMatrix::duplicate() const
 	}
 	else
 		dupl->jd = 0;
-	
+
 	dupl->doFreeMemory( );
 
 	return dupl;
@@ -609,7 +743,7 @@ Matrix *SparseMatrix::duplicate() const
 
 
 
-real_t SparseMatrix::diag(int i) const
+real_t SparseMatrix::diag(int_t i) const
 {
 	if ( jd == 0 )
 	{
@@ -617,43 +751,43 @@ real_t SparseMatrix::diag(int i) const
 		return INFTY;
 	}
 
-	int entry = jd[i];
+	int_t entry = jd[i];
 	return (entry < jc[i+1] && ir[entry] == i) ? val[entry] : 0.0;
 }
 
 
 BooleanType SparseMatrix::isDiag() const
 {
-	int j;
-	
+	int_t j;
+
 	if ( nCols != nRows )
 		return BT_FALSE;
-	
+
 	for (j = 0; j < nCols; ++j)
 	{
 		if ( jc[j+1] > jc[j]+1 )
 			return BT_FALSE;
-		
+
 		if ( ( jc[j+1] == jc[j]+1 ) && ( ir[jc[j]] != j ) )
 			return BT_FALSE;
 	}
-	
+
 	return BT_TRUE;
 }
 
 
 
-real_t SparseMatrix::getNorm(	int type
+real_t SparseMatrix::getNorm(	int_t type
 								) const
 {
-	int length = jc[nCols];
+	int_t length = jc[nCols];
 	return REFER_NAMESPACE_QPOASES getNorm( val,length,type );
 }
 
 
-real_t SparseMatrix::getRowNorm( int rNum, int type ) const
+real_t SparseMatrix::getRowNorm( int_t rNum, int_t type ) const
 {
-    int i,j;
+    int_t i,j;
     real_t norm = 0.0;
 
 	switch( type )
@@ -679,7 +813,7 @@ real_t SparseMatrix::getRowNorm( int rNum, int type ) const
 }
 
 
-returnValue SparseMatrix::getRow(int rNum, const Indexlist* const icols, real_t alpha, real_t *row) const
+returnValue SparseMatrix::getRow(int_t rNum, const Indexlist* const icols, real_t alpha, real_t *row) const
 {
 	long i, j, k;
 
@@ -732,7 +866,7 @@ returnValue SparseMatrix::getRow(int rNum, const Indexlist* const icols, real_t
 }
 
 
-returnValue SparseMatrix::getCol(int cNum, const Indexlist* const irows, real_t alpha, real_t *col) const
+returnValue SparseMatrix::getCol(int_t cNum, const Indexlist* const irows, real_t alpha, real_t *col) const
 {
 	long i, j;
 
@@ -770,9 +904,102 @@ returnValue SparseMatrix::getCol(int cNum, const Indexlist* const irows, real_t
 	return SUCCESSFUL_RETURN;
 }
 
+returnValue SparseMatrix::getSparseSubmatrix (int_t irowsLength, const int_t* const irowsNumber,
+											  int_t icolsLength, const int_t* const icolsNumber,
+											  int_t rowoffset, int_t coloffset, int_t& numNonzeros,	int_t* irn,
+											  int_t* jcn, real_t* avals,
+											  BooleanType only_lower_triangular /*= BT_FALSE */) const
+{
+	int_t i, j, k, l;
 
-returnValue SparseMatrix::times(int xN, real_t alpha, const real_t *x, int xLD,
-		real_t beta, real_t *y, int yLD) const
+	// Compute the "inverse" of the irows->number array
+	// TODO: Ideally this should be a part of Indexlist
+	int_t* rowNumberInv = new int_t[nRows];
+	for (i=0; i<nRows; i++)
+		rowNumberInv[i] = -1;
+	for (i=0; i<irowsLength; i++)
+		rowNumberInv[irowsNumber[i]] = i;
+
+	numNonzeros = 0;
+	if ( only_lower_triangular == BT_FALSE )
+	{
+		if (irn == 0)
+		{
+			if (jcn != 0 || avals != 0)
+				return THROWERROR( RET_INVALID_ARGUMENTS );
+			for (k = 0; k < icolsLength; k++)
+			{
+				j = icolsNumber[k];
+				for (i = jc[j]; i < jc[j+1]; i++)
+				{
+					l = rowNumberInv[ir[i]];
+					if (l >= 0)
+						numNonzeros++;
+				}
+			}
+		}
+		else
+		{
+			for (k = 0; k < icolsLength; k++)
+			{
+				j = icolsNumber[k];
+				for (i = jc[j]; i < jc[j+1]; i++)
+				{
+					l = rowNumberInv[ir[i]];
+					if (l >= 0)
+					{
+						irn[numNonzeros] = l+rowoffset;
+						jcn[numNonzeros] = k+coloffset;
+						avals[numNonzeros] = val[i];
+						numNonzeros++;
+					}
+				}
+			}
+		}
+	}
+	else
+	{
+		if (irn == 0)
+		{
+			if (jcn != 0 || avals != 0)
+				return THROWERROR( RET_INVALID_ARGUMENTS );
+			for (k = 0; k < icolsLength; k++)
+			{
+				j = icolsNumber[k];
+				for (i = jc[j]; i < jc[j+1]; i++)
+				{
+					l = rowNumberInv[ir[i]];
+					if (l >= k)
+						numNonzeros++;
+				}
+			}
+		}
+		else
+		{
+			for (k = 0; k < icolsLength; k++)
+			{
+				j = icolsNumber[k];
+				for (i = jc[j]; i < jc[j+1]; i++)
+				{
+					l = rowNumberInv[ir[i]];
+					if (l >= k)
+					{
+						irn[numNonzeros] = l+rowoffset;
+						jcn[numNonzeros] = k+coloffset;
+						avals[numNonzeros] = val[i];
+						numNonzeros++;
+					}
+				}
+			}
+		}
+	}
+	delete [] rowNumberInv;
+
+	return SUCCESSFUL_RETURN;
+}
+
+returnValue SparseMatrix::times(int_t xN, real_t alpha, const real_t *x, int_t xLD,
+		real_t beta, real_t *y, int_t yLD) const
 {
 	long i, j, k;
 
@@ -809,8 +1036,8 @@ returnValue SparseMatrix::times(int xN, real_t alpha, const real_t *x, int xLD,
 }
 
 
-returnValue SparseMatrix::transTimes(int xN, real_t alpha, const real_t *x, int xLD,
-		real_t beta, real_t *y, int yLD) const
+returnValue SparseMatrix::transTimes(int_t xN, real_t alpha, const real_t *x, int_t xLD,
+		real_t beta, real_t *y, int_t yLD) const
 {
 	long i, j, k;
 
@@ -848,241 +1075,176 @@ returnValue SparseMatrix::transTimes(int xN, real_t alpha, const real_t *x, int
 
 
 returnValue SparseMatrix::times(const Indexlist* const irows, const Indexlist* const icols,
-		int xN, real_t alpha, const real_t *x, int xLD, real_t beta, real_t *y, int yLD,
+		int_t xN, real_t alpha, const real_t *x, int_t xLD, real_t beta, real_t *y, int_t yLD,
 		BooleanType yCompr) const
 {
 	long i, j, k, l, col;
+	real_t xcol;
+
+	if ( isEqual(alpha,0.0) == BT_TRUE )
+	{
+		if (yCompr == BT_TRUE)
+		{
+			if ( isZero(beta) == BT_TRUE )
+				for (k = 0; k < xN; k++)
+					for (j = 0; j < irows->length; j++)
+						y[j+k*yLD] = 0.0;
+			else if ( isEqual(beta,-1.0) == BT_TRUE )
+				for (k = 0; k < xN; k++)
+					for (j = 0; j < irows->length; j++)
+						y[j+k*yLD] = -y[j+k*yLD];
+			else if ( isEqual(beta,1.0) == BT_FALSE )
+				for (k = 0; k < xN; k++)
+					for (j = 0; j < irows->length; j++)
+						y[j+k*yLD] *= beta;
+		}
+		else
+		{
+			if (isZero( beta ) == BT_TRUE)
+				for (k = 0; k < xN; k++)
+					for (j = 0; j < irows->length; j++)
+						y[irows->number[j]+k*yLD] = 0.0;
+			else if (isEqual( beta, -1.0 ) == BT_TRUE)
+				for (k = 0; k < xN; k++)
+					for (j = 0; j < irows->length; j++)
+						y[irows->number[j]+k*yLD] = -y[irows->number[j]+k*yLD];
+			else if (isEqual( beta, 1.0 ) == BT_FALSE)
+				for (k = 0; k < xN; k++)
+					for (j = 0; j < irows->length; j++)
+						y[irows->number[j]+k*yLD] *= beta;
+		}
+		return SUCCESSFUL_RETURN;
+	}
+
+	// First, work with full, unordered copy of y and store matrix times x in there
+	const int_t yfullLength = nRows;
+	real_t* ytmp = new real_t[xN*yfullLength];
+	for (k = 0; k < xN*yfullLength; k++)
+		ytmp[k] = 0.0;
+
+	if (icols!=0)
+	{
+		if (xN==1)
+		{
+			for (l = 0; l < icols->length; l++)
+			{
+				col = icols->iSort[l];
+				xcol = x[col];
+				if (isZero( xcol ) == BT_FALSE)
+				{
+					j = icols->number[col];
+					for (i = jc[j]; i < jc[j+1]; i++)
+						ytmp[ir[i]] += val[i] * xcol;
+				}
+			}
+		}
+		else
+		{
+			// AW: I didn't test the case xN>1, but I hope it is working
+			real_t* xcols = new real_t[xN];
+			for (l = 0; l < icols->length; l++)
+			{
+				col = icols->iSort[l];
+				real_t xmax = 0.0;
+				for (k=0; k<xN; k++)
+				{
+					xcols[k] = x[k*xLD+col];
+					xmax = getMax(xmax,getAbs(xcols[k]));
+				}
+				if (isZero( xmax ) == BT_FALSE)
+				{
+					j = icols->number[col];
+					for (i = jc[j]; i < jc[j+1]; i++)
+						for (k=0; k<xN; k++)
+						  // AW: Maybe it makes more sense to order ytmp by vectors, not vector entries, for better cache peformance?
+							ytmp[k*yfullLength+ir[i]] += val[i] * xcols[k];
+				}
+			}
+			delete [] xcols;
+		}
+	}
+	else /* icols == 0 */
+	{
+		if (xN==1)
+		{
+			for (col = 0; col < nCols; col++)
+			{
+				xcol = x[col];
+				if (isZero( xcol ) == BT_FALSE)
+					for (i = jc[col]; i < jc[col+1]; i++)
+						ytmp[ir[i]] += val[i] * xcol;
+			}
+		}
+		else
+		{
+			// AW: I didn't test the case xN>1, but I hope it is working
+			real_t* xcols = new real_t[xN];
+			for (col = 0; col < nCols; col++)
+			{
+				real_t xmax = 0.0;
+				for (k=0; k<xN; k++)
+				{
+					xcols[k] = x[k*xLD+col];
+					xmax = getMax(xmax,getAbs(xcols[k]));
+				}
+				if (isZero( xmax ) == BT_FALSE)
+					for (i = jc[col]; i < jc[col+1]; i++)
+						for (k=0; k<xN; k++)
+							ytmp[k*yfullLength+ir[i]] += val[i] * xcols[k];
+				delete [] xcols;
+			}
+		}
+	}
 
 	if (yCompr == BT_TRUE)
 	{
 		if ( isZero(beta) == BT_TRUE )
 			for (k = 0; k < xN; k++)
 				for (j = 0; j < irows->length; j++)
-					y[j+k*yLD] = 0.0;
-		else if ( isEqual(beta,-1.0) == BT_TRUE )
+					y[j+k*yLD] = alpha*ytmp[irows->number[j]+k*yfullLength];
+		else if (isEqual( beta, 1.0 ) == BT_TRUE)
 			for (k = 0; k < xN; k++)
 				for (j = 0; j < irows->length; j++)
-					y[j+k*yLD] = -y[j+k*yLD];
-		else if ( isEqual(beta,1.0) == BT_FALSE )
+					y[j+k*yLD] += alpha*ytmp[irows->number[j]+k*yfullLength];
+		else if (isEqual( beta, -1.0 ) == BT_TRUE)
 			for (k = 0; k < xN; k++)
 				for (j = 0; j < irows->length; j++)
-					y[j+k*yLD] *= beta;
-
-		if (icols == 0)
-			if ( isEqual(alpha,1.0) == BT_TRUE )
-				for (l = 0; l < nCols; l++)
-				{
-					i = jc[l];
-					j = 0;
-					while (i < jc[l+1] && j < irows->length)
-						if (ir[i] == irows->number[irows->iSort[j]])
-						{
-							for (k = 0; k < xN; k++)
-								y[k*yLD+irows->iSort[j]] += val[i] * x[k*xLD+l];
-							i++, j++;
-						}
-						else if (ir[i] > irows->number[irows->iSort[j]]) j++;
-						else i++;
-				}
-			else if ( isEqual(alpha,-1.0) == BT_TRUE )
-				for (l = 0; l < nCols; l++)
-				{
-					i = jc[l];
-					j = 0;
-					while (i < jc[l+1] && j < irows->length)
-						if (ir[i] == irows->number[irows->iSort[j]])
-						{
-							for (k = 0; k < xN; k++)
-								y[k*yLD+irows->iSort[j]] -= val[i] * x[k*xLD+l];
-							i++, j++;
-						}
-						else if (ir[i] > irows->number[irows->iSort[j]]) j++;
-						else i++;
-				}
-			else
-				for (l = 0; l < nCols; l++)
-				{
-					i = jc[l];
-					j = 0;
-					while (i < jc[l+1] && j < irows->length)
-						if (ir[i] == irows->number[irows->iSort[j]])
-						{
-							for (k = 0; k < xN; k++)
-								y[k*yLD+irows->iSort[j]] += alpha * val[i] * x[k*xLD+l];
-							i++, j++;
-						}
-						else if (ir[i] > irows->number[irows->iSort[j]]) j++;
-						else i++;
-				}
-		else /* icols != 0 */
-			if ( isEqual(alpha,1.0) == BT_TRUE )
-				for (l = 0; l < icols->length; l++)
-				{
-					col = icols->iSort[l];
-					i = jc[icols->number[col]];
-					j = 0;
-					while (i < jc[icols->number[col]+1] && j < irows->length)
-						if (ir[i] == irows->number[irows->iSort[j]])
-						{
-							for (k = 0; k < xN; k++)
-								y[k*yLD+irows->iSort[j]] += val[i] * x[k*xLD+col];
-							i++, j++;
-						}
-						else if (ir[i] > irows->number[irows->iSort[j]]) j++;
-						else i++;
-				}
-			else if ( isEqual(alpha,-1.0) == BT_TRUE )
-				for (l = 0; l < icols->length; l++)
-				{
-					col = icols->iSort[l];
-					i = jc[icols->number[col]];
-					j = 0;
-					while (i < jc[icols->number[col]+1] && j < irows->length)
-						if (ir[i] == irows->number[irows->iSort[j]])
-						{
-							for (k = 0; k < xN; k++)
-								y[k*yLD+irows->iSort[j]] -= val[i] * x[k*xLD+col];
-							i++, j++;
-						}
-						else if (ir[i] > irows->number[irows->iSort[j]]) j++;
-						else i++;
-				}
-			else
-				for (l = 0; l < icols->length; l++)
-				{
-					col = icols->iSort[l];
-					i = jc[icols->number[col]];
-					j = 0;
-					while (i < jc[icols->number[col]+1] && j < irows->length)
-						if (ir[i] == irows->number[irows->iSort[j]])
-						{
-							for (k = 0; k < xN; k++)
-								y[k*yLD+irows->iSort[j]] += alpha * val[i] * x[k*xLD+col];
-							i++, j++;
-						}
-						else if (ir[i] > irows->number[irows->iSort[j]]) j++;
-						else i++;
-				}
+					y[j+k*yLD] = alpha*ytmp[irows->number[j]+k*yfullLength]-y[j+k*yLD];
+		else if (isEqual( beta, 1.0 ) == BT_FALSE)
+			for (k = 0; k < xN; k++)
+				for (j = 0; j < irows->length; j++)
+					y[j+k*yLD] = alpha*ytmp[irows->number[j]+k*yfullLength]+beta*y[j+k*yLD];
 	}
-	else /* y not compressed */
+	else
 	{
-		if ( isZero(beta) == BT_TRUE )
+		if (isZero( beta ) == BT_TRUE)
 			for (k = 0; k < xN; k++)
 				for (j = 0; j < irows->length; j++)
-					y[irows->number[j]+k*yLD] = 0.0;
-		else if ( isEqual(beta,-1.0) == BT_TRUE )
+					y[irows->number[j]+k*yLD] = alpha*ytmp[irows->number[j]+k*yfullLength];
+		else if (isEqual( beta, 1.0 ) == BT_TRUE)
 			for (k = 0; k < xN; k++)
 				for (j = 0; j < irows->length; j++)
-					y[irows->number[j]+k*yLD] = -y[j+k*yLD];
-		else if ( isEqual(beta,1.0) == BT_FALSE )
+					y[irows->number[j]+k*yLD] = alpha*ytmp[irows->number[j]+k*yfullLength]+y[j+k*yLD];
+		else if (isEqual( beta, -1.0 ) == BT_TRUE)
 			for (k = 0; k < xN; k++)
 				for (j = 0; j < irows->length; j++)
-					y[irows->number[j]+k*yLD] *= beta;
-
-		if (icols == 0)
-			if ( isEqual(alpha,1.0) == BT_TRUE )
-				for (l = 0; l < nCols; l++)
-				{
-					i = jc[l];
-					j = 0;
-					while (i < jc[l+1] && j < irows->length)
-						if (ir[i] == irows->number[irows->iSort[j]])
-						{
-							for (k = 0; k < xN; k++)
-								y[k*yLD+irows->number[irows->iSort[j]]] += val[i] * x[k*xLD+l];
-							i++, j++;
-						}
-						else if (ir[i] > irows->number[irows->iSort[j]]) j++;
-						else i++;
-				}
-			else if ( isEqual(alpha,-1.0) == BT_TRUE )
-				for (l = 0; l < nCols; l++)
-				{
-					i = jc[l];
-					j = 0;
-					while (i < jc[l+1] && j < irows->length)
-						if (ir[i] == irows->number[irows->iSort[j]])
-						{
-							for (k = 0; k < xN; k++)
-								y[k*yLD+irows->number[irows->iSort[j]]] -= val[i] * x[k*xLD+l];
-							i++, j++;
-						}
-						else if (ir[i] > irows->number[irows->iSort[j]]) j++;
-						else i++;
-				}
-			else
-				for (l = 0; l < nCols; l++)
-				{
-					i = jc[l];
-					j = 0;
-					while (i < jc[l+1] && j < irows->length)
-						if (ir[i] == irows->number[irows->iSort[j]])
-						{
-							for (k = 0; k < xN; k++)
-								y[k*yLD+irows->number[irows->iSort[j]]] += alpha * val[i] * x[k*xLD+l];
-							i++, j++;
-						}
-						else if (ir[i] > irows->number[irows->iSort[j]]) j++;
-						else i++;
-				}
-		else /* icols != 0 */
-			if ( isEqual(alpha,1.0) == BT_TRUE )
-				for (l = 0; l < icols->length; l++)
-				{
-					col = icols->iSort[l];
-					i = jc[icols->number[col]];
-					j = 0;
-					while (i < jc[icols->number[col]+1] && j < irows->length)
-						if (ir[i] == irows->number[irows->iSort[j]])
-						{
-							for (k = 0; k < xN; k++)
-								y[k*yLD+irows->number[irows->iSort[j]]] += val[i] * x[k*xLD+col];
-							i++, j++;
-						}
-						else if (ir[i] > irows->number[irows->iSort[j]]) j++;
-						else i++;
-				}
-			else if ( isEqual(alpha,-1.0) == BT_TRUE )
-				for (l = 0; l < icols->length; l++)
-				{
-					col = icols->iSort[l];
-					i = jc[icols->number[col]];
-					j = 0;
-					while (i < jc[icols->number[col]+1] && j < irows->length)
-						if (ir[i] == irows->number[irows->iSort[j]])
-						{
-							for (k = 0; k < xN; k++)
-								y[k*yLD+irows->number[irows->iSort[j]]] -= val[i] * x[k*xLD+col];
-							i++, j++;
-						}
-						else if (ir[i] > irows->number[irows->iSort[j]]) j++;
-						else i++;
-				}
-			else
-				for (l = 0; l < icols->length; l++)
-				{
-					col = icols->iSort[l];
-					i = jc[icols->number[col]];
-					j = 0;
-					while (i < jc[icols->number[col]+1] && j < irows->length)
-						if (ir[i] == irows->number[irows->iSort[j]])
-						{
-							for (k = 0; k < xN; k++)
-								y[k*yLD+irows->number[irows->iSort[j]]] += alpha * val[i] * x[k*xLD+col];
-							i++, j++;
-						}
-						else if (ir[i] > irows->number[irows->iSort[j]]) j++;
-						else i++;
-				}
+					y[irows->number[j]+k*yLD] = alpha*ytmp[irows->number[j]+k*yfullLength]-y[j+k*yLD];
+		else if (isEqual( beta, 1.0 ) == BT_FALSE)
+			for (k = 0; k < xN; k++)
+				for (j = 0; j < irows->length; j++)
+					y[irows->number[j]+k*yLD] = alpha*ytmp[irows->number[j]+k*yfullLength]+beta*y[j+k*yLD];
 	}
+
+	delete [] ytmp;
 	return SUCCESSFUL_RETURN;
 }
 
 
 returnValue SparseMatrix::transTimes(const Indexlist* const irows, const Indexlist* const icols,
-		int xN, real_t alpha, const real_t *x, int xLD, real_t beta, real_t *y, int yLD) const
+		int_t xN, real_t alpha, const real_t *x, int_t xLD, real_t beta, real_t *y, int_t yLD) const
 {
 	long i, j, k, l, col;
+	real_t yadd;
 
 	if ( isZero(beta) == BT_TRUE )
 		for (k = 0; k < xN; k++)
@@ -1096,55 +1258,31 @@ returnValue SparseMatrix::transTimes(const Indexlist* const irows, const Indexli
 		for (k = 0; k < xN; k++)
 			for (j = 0; j < icols->length; j++)
 				y[j+k*yLD] *= beta;
+	if ( isEqual(alpha,0.0) == BT_TRUE )
+		return SUCCESSFUL_RETURN;
 
-	if ( isEqual(alpha,1.0) == BT_TRUE )
+	// work with full, unordered copy of x
+	const int_t xfullLength = nRows;
+	real_t* xtmp = new real_t[xfullLength];
+	for (k = 0; k < xN; k++)
+	{
+		for (i = 0; i < xfullLength; i++)
+			xtmp[i] = 0.0;
+		for (i = 0; i < irows->length; i++)
+			xtmp[irows->number[i]] = x[k*xLD+i];
 		for (l = 0; l < icols->length; l++)
 		{
 			col = icols->iSort[l];
-			i = jc[icols->number[col]];
-			j = 0;
-			while (i < jc[icols->number[col]+1] && j < irows->length)
-				if (ir[i] == irows->number[irows->iSort[j]])
-				{
-					for (k = 0; k < xN; k++)
-						y[k*yLD+col] += val[i] * x[k*xLD+irows->iSort[j]];
-					i++, j++;
-				}
-				else if (ir[i] > irows->number[irows->iSort[j]]) j++;
-				else i++;
-		}
-	else if ( isEqual(alpha,-1.0) == BT_TRUE )
-		for (l = 0; l < icols->length; l++)
-		{
-			col = icols->iSort[l];
-			i = jc[icols->number[col]];
-			j = 0;
-			while (i < jc[icols->number[col]+1] && j < irows->length)
-				if (ir[i] == irows->number[irows->iSort[j]])
-				{
-					for (k = 0; k < xN; k++)
-						y[k*yLD+col] -= val[i] * x[k*xLD+irows->iSort[j]];
-					i++, j++;
-				}
-				else if (ir[i] > irows->number[irows->iSort[j]]) j++;
-				else i++;
-		}
-	else
-		for (l = 0; l < icols->length; l++)
-		{
-			col = icols->iSort[l];
-			i = jc[icols->number[col]];
-			j = 0;
-			while (i < jc[icols->number[col]+1] && j < irows->length)
-				if (ir[i] == irows->number[irows->iSort[j]])
-				{
-					for (k = 0; k < xN; k++)
-						y[k*yLD+col] += alpha * val[i] * x[k*xLD+irows->iSort[j]];
-					i++, j++;
-				}
-				else if (ir[i] > irows->number[irows->iSort[j]]) j++;
-				else i++;
+			yadd = 0.0;
+			j = icols->number[col];
+			for (i = jc[j]; i < jc[j+1]; i++)
+				yadd += val[i] * xtmp[ir[i]];
+			y[col] += alpha*yadd;
 		}
+		y += yLD; // move on to next RHS
+	}
+
+	delete [] xtmp;
 
 	return SUCCESSFUL_RETURN;
 }
@@ -1154,7 +1292,7 @@ returnValue SparseMatrix::transTimes(const Indexlist* const irows, const Indexli
 returnValue SparseMatrix::addToDiag(real_t alpha)
 {
 	long i;
-	
+
 	if ( jd == 0 )
 		return THROWERROR( RET_DIAGONAL_NOT_INITIALISED );
 
@@ -1217,18 +1355,30 @@ returnValue SparseMatrix::print( const char* name ) const
 	return retVal;
 }
 
+returnValue SparseMatrix::writeToFile( FILE* output_file, const char* prefix ) const
+{
+	for (int_t i=0; i<=nCols; i++) {
+		fprintf( output_file,"%sjc[%d] = %d\n",prefix,(int)i,(int)(jc[i]) );
+	}
+	for (int_t i=0; i<jc[nCols]; i++) {
+		fprintf( output_file,"%sir[%d] = %d\n",prefix,(int)i,(int)(ir[i]) );
+	}
+	for (int_t i=0; i<jc[nCols]; i++) {
+		fprintf( output_file,"%sval[%d] = %23.16e\n",prefix,(int)i,val[i] );
+	}
+
+	return SUCCESSFUL_RETURN;
+}
 
 
 SparseMatrixRow::SparseMatrixRow() : nRows(0), nCols(0), jr(0), ic(0), jd(0), val(0) {}
 
-
-SparseMatrixRow::SparseMatrixRow(int nr, int nc, sparse_int_t *r, sparse_int_t *c, real_t *v)
+SparseMatrixRow::SparseMatrixRow(int_t nr, int_t nc, sparse_int_t *r, sparse_int_t *c, real_t *v)
 	: nRows(nr), nCols(nc), jr(r), ic(c), jd(0), val(v) { doNotFreeMemory(); }
 
-
-SparseMatrixRow::SparseMatrixRow(int nr, int nc, int ld, const real_t * const v) : nRows(nr), nCols(nc), jd(0)
+SparseMatrixRow::SparseMatrixRow(int_t nr, int_t nc, int_t ld, const real_t * const v) : nRows(nr), nCols(nc), jd(0)
 {
-	int i, j, nnz;
+	int_t i, j, nnz;
 
 	jr = new sparse_int_t[nr+1];
 	ic = new sparse_int_t[nr*nc];
@@ -1307,7 +1457,7 @@ Matrix *SparseMatrixRow::duplicate() const
 
 
 
-real_t SparseMatrixRow::diag(int i) const
+real_t SparseMatrixRow::diag(int_t i) const
 {
 	if ( jd == 0 )
 	{
@@ -1315,50 +1465,50 @@ real_t SparseMatrixRow::diag(int i) const
 		return INFTY;
 	}
 
-	int entry = jd[i];
+	int_t entry = jd[i];
 	return (entry < jr[i+1] && ic[entry] == i) ? val[entry] : 0.0;
 }
 
 
 BooleanType SparseMatrixRow::isDiag() const
 {
-	int i;
-	
+	int_t i;
+
 	if ( nCols != nRows )
 		return BT_FALSE;
-	
+
 	for (i = 0; i < nRows; ++i)
 	{
 		if ( jr[i+1] > jr[i]+1 )
 			return BT_FALSE;
-		
+
 		if ( ( jr[i+1] == jr[i]+1 ) && ( ic[jr[i]] != i ) )
 			return BT_FALSE;
 	}
-	
+
 	return BT_TRUE;
 }
 
 
 
-real_t SparseMatrixRow::getNorm(	int type
+real_t SparseMatrixRow::getNorm(	int_t type
 									) const
 {
-	int length = jr[nRows];
+	int_t length = jr[nRows];
 	return REFER_NAMESPACE_QPOASES getNorm( val,length,type );
 
 }
 
 
-real_t SparseMatrixRow::getRowNorm( int rNum, int type ) const
+real_t SparseMatrixRow::getRowNorm( int_t rNum, int_t type ) const
 {
-	int length = jr[rNum+1] - jr[rNum];
+	int_t length = jr[rNum+1] - jr[rNum];
 	return REFER_NAMESPACE_QPOASES getNorm( &(val[jr[rNum]]),length,type );
 }
 
 
 
-returnValue SparseMatrixRow::getRow(int rNum, const Indexlist* const icols, real_t alpha, real_t *row) const
+returnValue SparseMatrixRow::getRow(int_t rNum, const Indexlist* const icols, real_t alpha, real_t *row) const
 {
 	long i, j;
 
@@ -1415,7 +1565,7 @@ returnValue SparseMatrixRow::getRow(int rNum, const Indexlist* const icols, real
 }
 
 
-returnValue SparseMatrixRow::getCol(int cNum, const Indexlist* const irows, real_t alpha, real_t *col) const
+returnValue SparseMatrixRow::getCol(int_t cNum, const Indexlist* const irows, real_t alpha, real_t *col) const
 {
 	long i, j, k, srt;
 
@@ -1470,10 +1620,19 @@ returnValue SparseMatrixRow::getCol(int cNum, const Indexlist* const irows, real
 	return SUCCESSFUL_RETURN;
 }
 
+returnValue SparseMatrixRow::getSparseSubmatrix (
+				int_t irowsLength, const int_t* const irowsNumber,
+				int_t icolsLength, const int_t* const icolsNumber,
+				int_t rowoffset, int_t coloffset, int_t& numNonzeros,	int_t* irn,
+				int_t* jcn, real_t* avals, BooleanType only_lower_triangular /*= BT_FALSE */) const
+{
+	fprintf(stderr, "SparseMatrixRow::getSparseSubmatrix not implemented!\n");
 
+	return THROWERROR(RET_NOT_YET_IMPLEMENTED);
+}
 
-returnValue SparseMatrixRow::times(int xN, real_t alpha, const real_t *x, int xLD,
-		real_t beta, real_t *y, int yLD) const
+returnValue SparseMatrixRow::times(int_t xN, real_t alpha, const real_t *x, int_t xLD,
+		real_t beta, real_t *y, int_t yLD) const
 {
 	long i, j, k;
 
@@ -1510,8 +1669,8 @@ returnValue SparseMatrixRow::times(int xN, real_t alpha, const real_t *x, int xL
 }
 
 
-returnValue SparseMatrixRow::transTimes(int xN, real_t alpha, const real_t *x, int xLD,
-		real_t beta, real_t *y, int yLD) const
+returnValue SparseMatrixRow::transTimes(int_t xN, real_t alpha, const real_t *x, int_t xLD,
+		real_t beta, real_t *y, int_t yLD) const
 {
 	long i, j, k;
 
@@ -1549,7 +1708,7 @@ returnValue SparseMatrixRow::transTimes(int xN, real_t alpha, const real_t *x, i
 
 
 returnValue SparseMatrixRow::times(const Indexlist* const irows, const Indexlist* const icols,
-		int xN, real_t alpha, const real_t *x, int xLD, real_t beta, real_t *y, int yLD,
+		int_t xN, real_t alpha, const real_t *x, int_t xLD, real_t beta, real_t *y, int_t yLD,
 		BooleanType yCompr) const
 {
 	long i, j, k, l, srt, row;
@@ -1745,7 +1904,7 @@ returnValue SparseMatrixRow::times(const Indexlist* const irows, const Indexlist
 
 
 returnValue SparseMatrixRow::transTimes(const Indexlist* const irows, const Indexlist* const icols,
-		int xN, real_t alpha, const real_t *x, int xLD, real_t beta, real_t *y, int yLD) const
+		int_t xN, real_t alpha, const real_t *x, int_t xLD, real_t beta, real_t *y, int_t yLD) const
 {
 	long i, j, k, l, row, srt;
 
@@ -1822,7 +1981,7 @@ returnValue SparseMatrixRow::transTimes(const Indexlist* const irows, const Inde
 returnValue SparseMatrixRow::addToDiag(real_t alpha)
 {
 	long i;
-	
+
 	if ( jd == 0 )
 		return THROWERROR( RET_DIAGONAL_NOT_INITIALISED );
 
@@ -1884,7 +2043,10 @@ returnValue SparseMatrixRow::print( const char* name ) const
 	return retVal;
 }
 
-
+returnValue SparseMatrixRow::writeToFile( FILE* output_file, const char* prefix ) const
+{
+	return THROWERROR( RET_NOT_YET_IMPLEMENTED );
+}
 
 Matrix *SymSparseMat::duplicate() const
 {
@@ -1923,9 +2085,9 @@ SymmetricMatrix *SymSparseMat::duplicateSym() const
 
 
 returnValue SymSparseMat::bilinear(const Indexlist* const icols,
-		int xN, const real_t *x, int xLD, real_t *y, int yLD) const
+		int_t xN, const real_t *x, int_t xLD, real_t *y, int_t yLD) const
 {
-	int i, j, k, l, idx, row, col;
+	int_t i, j, k, l, idx, row, col;
 
 	if ( jd == 0 )
 		return THROWERROR( RET_DIAGONAL_NOT_INITIALISED );
