@@ -25,7 +25,7 @@
 /**
  *	\file src/MessageHandling.cpp
  *	\author Hans Joachim Ferreau, Andreas Potschka, Christian Kirches
- *	\version 3.1
+ *	\version 3.2
  *	\date 2007-2015
  *
  *	Implementation of the MessageHandling class including global return values.
@@ -208,6 +208,11 @@ MessageHandling::ReturnValueList returnValueList[] =
 { RET_DIAGONAL_NOT_INITIALISED, "Diagonal data of sparse matrix has not been initialised", VS_VISIBLE },
 /* Dropping of infeasible constraints */
 { RET_ENSURELI_DROPPED, "Linear independence resolved by dropping blocking constraint", VS_VISIBLE },
+/* Schur complement computations */
+{ RET_KKT_MATRIX_SINGULAR, "KKT matrix is singular", VS_VISIBLE },
+{ RET_QR_FACTORISATION_FAILED, "QR factorization of Schur complement failed", VS_VISIBLE },
+{ RET_INERTIA_CORRECTION_FAILED, "Inertia correction of KKT matrix failed", VS_VISIBLE },
+{ RET_NO_SPARSE_SOLVER, "No Sparse Solver installed", VS_VISIBLE },
 /* Simple exitflags */
 { RET_SIMPLE_STATUS_P1, "QP problem could not be solved within given number of iterations", VS_VISIBLE },
 { RET_SIMPLE_STATUS_P0, "QP problem solved", VS_VISIBLE },
@@ -249,8 +254,8 @@ MessageHandling::MessageHandling( )
 MessageHandling::MessageHandling( FILE* _outputFile )
 {
 	errorVisibility   = VS_VISIBLE;
-	warningVisibility = VS_VISIBLE;
-	infoVisibility    = VS_VISIBLE;
+	warningVisibility = VS_HIDDEN;
+	infoVisibility    = VS_HIDDEN;
 
 	outputFile = _outputFile;
 	errorCount = 0;
@@ -339,14 +344,13 @@ MessageHandling& MessageHandling::operator=( const MessageHandling& rhs )
 /*
  *	t h r o w E r r o r
  */
-returnValue MessageHandling::throwError(
-	returnValue Enumber,
-	const char* additionaltext,
-	const char* functionname,
-	const char* filename,
-	const unsigned long linenumber,
-	VisibilityStatus localVisibilityStatus
-	)
+returnValue MessageHandling::throwError(	returnValue Enumber,
+											const char* additionaltext,
+											const char* functionname,
+											const char* filename,
+											const unsigned long linenumber,
+											VisibilityStatus localVisibilityStatus
+											)
 {
 	/* consistency check */
 	if ( Enumber <= SUCCESSFUL_RETURN )
@@ -363,14 +367,13 @@ returnValue MessageHandling::throwError(
 /*
  *	t h r o w W a r n i n g
  */
-returnValue MessageHandling::throwWarning(
-	returnValue Wnumber,
-	const char* additionaltext,
-	const char* functionname,
-	const char* filename,
-	const unsigned long linenumber,
-	VisibilityStatus localVisibilityStatus
-  	)
+returnValue MessageHandling::throwWarning(	returnValue Wnumber,
+											const char* additionaltext,
+											const char* functionname,
+											const char* filename,
+											const unsigned long linenumber,
+											VisibilityStatus localVisibilityStatus
+											)
 {
 	/* consistency check */
   	if ( Wnumber <= SUCCESSFUL_RETURN )
@@ -387,14 +390,13 @@ returnValue MessageHandling::throwWarning(
 /*
  *	t h r o w I n f o
  */
-returnValue MessageHandling::throwInfo(
-  	returnValue Inumber,
-	const char* additionaltext,
-  	const char* functionname,
-	const char* filename,
-	const unsigned long linenumber,
-	VisibilityStatus localVisibilityStatus
- 	)
+returnValue MessageHandling::throwInfo(	returnValue Inumber,
+										const char* additionaltext,
+										const char* functionname,
+										const char* filename,
+										const unsigned long linenumber,
+										VisibilityStatus localVisibilityStatus
+										)
 {
 	/* consistency check */
 	if ( Inumber < SUCCESSFUL_RETURN )
@@ -414,8 +416,8 @@ returnValue MessageHandling::throwInfo(
 returnValue MessageHandling::reset( )
 {
 	setErrorVisibilityStatus(   VS_VISIBLE );
-	setWarningVisibilityStatus( VS_VISIBLE );
-	setInfoVisibilityStatus(    VS_VISIBLE );
+	setWarningVisibilityStatus( VS_HIDDEN );
+	setInfoVisibilityStatus(    VS_HIDDEN );
 
 	setOutputFile( stdFile );
 	setErrorCount( 0 );
@@ -430,13 +432,13 @@ returnValue MessageHandling::reset( )
 returnValue MessageHandling::listAllMessages( )
 {
 	#ifndef __SUPPRESSANYOUTPUT__
-	int keypos = 0;
+	int_t keypos = 0;
 	char myPrintfString[MAX_STRING_LENGTH];
 
 	/* Run through whole returnValueList and print each item. */
 	while ( returnValueList[keypos].key != TERMINAL_LIST_ELEMENT )
 	{
-		snprintf( myPrintfString,MAX_STRING_LENGTH," %d - %s \n",keypos,returnValueList[keypos].data );
+		snprintf( myPrintfString,MAX_STRING_LENGTH," %d - %s \n",(int)keypos,returnValueList[keypos].data );
 		myPrintf( myPrintfString );
 
 		++keypos;
@@ -456,24 +458,23 @@ returnValue MessageHandling::listAllMessages( )
 /*
  *	t h r o w M e s s a g e
  */
-returnValue MessageHandling::throwMessage(
-	returnValue RETnumber,
-	const char* additionaltext,
-	const char* functionname,
-	const char* filename,
-	const unsigned long linenumber,
-	VisibilityStatus localVisibilityStatus,
-	const char* RETstring
- 	)
+returnValue MessageHandling::throwMessage(	returnValue RETnumber,
+											const char* additionaltext,
+											const char* functionname,
+											const char* filename,
+											const unsigned long linenumber,
+											VisibilityStatus localVisibilityStatus,
+											const char* RETstring
+											)
 {
 	#ifndef __SUPPRESSANYOUTPUT__
 
-	int keypos = 0;
+	int_t keypos = 0;
 	char myPrintfString[MAX_STRING_LENGTH];
 
 	/* 1) Determine number of whitespace for output. */
 	char whitespaces[MAX_STRING_LENGTH];
-	int numberOfWhitespaces = (errorCount-1)*2;
+	int_t numberOfWhitespaces = (errorCount-1)*2;
 
 	if ( numberOfWhitespaces < 0 )
 		numberOfWhitespaces = 0;
@@ -481,8 +482,8 @@ returnValue MessageHandling::throwMessage(
 	if ( numberOfWhitespaces > 40 )
 		numberOfWhitespaces = 40;
 
-	if ( numberOfWhitespaces >= (int)MAX_STRING_LENGTH )
-		numberOfWhitespaces = (int)MAX_STRING_LENGTH-1;
+	if ( numberOfWhitespaces >= (int_t)MAX_STRING_LENGTH )
+		numberOfWhitespaces = (int_t)MAX_STRING_LENGTH-1;
 
 	memset( whitespaces, ' ', (size_t) numberOfWhitespaces );
 	whitespaces[numberOfWhitespaces] = '\0';
@@ -521,7 +522,7 @@ returnValue MessageHandling::throwMessage(
 		{
 			#ifdef __DEBUG__
 			snprintf(	myPrintfString,MAX_STRING_LENGTH,"%s (%s, %s:%d): \t%s\n",
-						RETstring,functionname,filename,(int)linenumber,returnValueList[keypos].data
+						RETstring,functionname,filename,(int_t)linenumber,returnValueList[keypos].data
 						);
 			#else
 			snprintf(	myPrintfString,MAX_STRING_LENGTH,"%s:  %s\n",
@@ -534,7 +535,7 @@ returnValue MessageHandling::throwMessage(
 		{
 			#ifdef __DEBUG__
 			snprintf(	myPrintfString,MAX_STRING_LENGTH,"%s (%s, %s:%d): \t%s %s\n",
-						RETstring,functionname,filename,(int)linenumber,returnValueList[keypos].data,additionaltext
+						RETstring,functionname,filename,(int_t)linenumber,returnValueList[keypos].data,additionaltext
 						);
 			#else
 			snprintf(	myPrintfString,MAX_STRING_LENGTH,"%s:  %s %s\n",
@@ -571,7 +572,7 @@ const char* MessageHandling::getErrorCodeMessage(	const returnValue _returnValue
 {
 	#ifndef __SUPPRESSANYOUTPUT__
 
-	int keypos = 0;
+	int_t keypos = 0;
 	
 	/* 2) Find error/warning/info in list. */
 	while ( returnValueList[keypos].key != TERMINAL_LIST_ELEMENT )
@@ -604,7 +605,7 @@ const char* MessageHandling::getErrorCodeMessage(	const returnValue _returnValue
 
 /** Global message handler for all qpOASES modules.*/
 #if defined(__DSPACE__) || defined(__XPCTARGET__)
-static MessageHandling globalMessageHandler( stdFile,VS_VISIBLE,VS_VISIBLE,VS_VISIBLE );
+static MessageHandling globalMessageHandler( stdFile,VS_VISIBLE,VS_HIDDEN,VS_HIDDEN );
 #endif
 
 
